@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 The jdeb developers.
+ * Copyright 2007-2018 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,14 @@
 
 package org.vafer.jdeb;
 
+import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
+import org.apache.commons.compress.archivers.tar.TarArchiveOutputStream;
+import org.apache.commons.compress.archivers.tar.TarConstants;
+import org.apache.commons.compress.archivers.zip.ZipEncoding;
+import org.apache.commons.compress.archivers.zip.ZipEncodingHelper;
+import org.apache.commons.compress.compressors.CompressorException;
+import org.vafer.jdeb.utils.Utils;
+
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -29,14 +37,6 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
-import org.apache.commons.compress.archivers.tar.TarArchiveOutputStream;
-import org.apache.commons.compress.archivers.tar.TarConstants;
-import org.apache.commons.compress.archivers.zip.ZipEncoding;
-import org.apache.commons.compress.archivers.zip.ZipEncodingHelper;
-import org.apache.commons.compress.compressors.CompressorException;
-import org.vafer.jdeb.utils.Utils;
-
 /**
  * Builds the data archive of the Debian package.
  */
@@ -78,21 +78,24 @@ class DataBuilder {
      * @param producers
      * @param output
      * @param checksums
-     * @param compression the compression method used for the data file
+     * @param options Options used to build the data file
      * @return
      * @throws java.security.NoSuchAlgorithmException
      * @throws java.io.IOException
      * @throws org.apache.commons.compress.compressors.CompressorException
      */
-    BigInteger buildData(Collection<DataProducer> producers, File output, final StringBuilder checksums, Compression compression) throws NoSuchAlgorithmException, IOException, CompressorException {
+    BigInteger buildData(Collection<DataProducer> producers, File output, final StringBuilder checksums, TarOptions options) throws NoSuchAlgorithmException, IOException, CompressorException {
 
         final File dir = output.getParentFile();
         if (dir != null && (!dir.exists() || !dir.isDirectory())) {
             throw new IOException("Cannot write data file at '" + output.getAbsolutePath() + "'");
         }
 
-        final TarArchiveOutputStream tarOutputStream = new TarArchiveOutputStream(compression.toCompressedOutputStream(new FileOutputStream(output)));
-        tarOutputStream.setLongFileMode(TarArchiveOutputStream.LONGFILE_GNU);
+        final TarArchiveOutputStream tarOutputStream = new TarArchiveOutputStream(
+            options.compression().toCompressedOutputStream(new FileOutputStream(output))
+        );
+        tarOutputStream.setLongFileMode(options.longFileMode());
+        tarOutputStream.setBigNumberMode(options.bigNumberMode());
 
         final MessageDigest digest = MessageDigest.getInstance("MD5");
 
@@ -109,7 +112,7 @@ class DataBuilder {
                 // Check group name
                 checkField(dirEntry.getUserName(), TarConstants.GNAMELEN);
 
-                dirEntry.setName(fixPath(dirEntry.getName()));
+                dirEntry.setName(fixPathTar(dirEntry.getName()));
 
                 createParentDirectories(dirEntry.getName(), dirEntry.getUserName(), dirEntry.getLongUserId(), dirEntry.getGroupName(), dirEntry.getLongGroupId());
 
@@ -129,7 +132,10 @@ class DataBuilder {
                 // Check group name
                 checkField(fileEntry.getGroupName(), TarConstants.GNAMELEN);
 
-                fileEntry.setName(fixPath(fileEntry.getName()));
+                // For md5sum
+                String rawFileEntryName = fileEntry.getName();
+
+                fileEntry.setName(fixPathTar(fileEntry.getName()));
 
                 createParentDirectories(fileEntry.getName(), fileEntry.getUserName(), fileEntry.getLongUserId(), fileEntry.getGroupName(), fileEntry.getLongGroupId());
 
@@ -158,7 +164,7 @@ class DataBuilder {
                 );
 
                 // append to file md5 list, two spaces to be compatible with GNU coreutils md5sum
-                checksums.append(md5).append("  ").append(fileEntry.getName()).append('\n');
+                checksums.append(md5).append("  ").append(fixPathMd5(rawFileEntryName)).append('\n');
             }
 
             public void onEachLink(TarArchiveEntry entry) throws IOException {
@@ -169,7 +175,7 @@ class DataBuilder {
                 // Check group name
                 checkField(entry.getGroupName(), TarConstants.GNAMELEN);
 
-                entry.setName(fixPath(entry.getName()));
+                entry.setName(fixPathTar(entry.getName()));
 
                 createParentDirectories(entry.getName(), entry.getUserName(), entry.getLongUserId(), entry.getGroupName(), entry.getLongGroupId());
 
@@ -213,7 +219,7 @@ class DataBuilder {
             }
 
             private void createParentDirectories( String filename, String user, long uid, String group, long gid ) throws IOException {
-                String dirname = fixPath(new File(filename).getParent());
+                String dirname = fixPathTar(new File(filename).getParent());
 
                 // Debian packages must have parent directories created
                 // before sub-directories or files can be installed.
@@ -267,7 +273,7 @@ class DataBuilder {
         return dataSize.count;
     }
 
-    private String fixPath( String path ) {
+    private String fixPathBase( String path ) {
         if (path == null || path.equals(".")) {
             return path;
         }
@@ -278,6 +284,16 @@ class DataBuilder {
         if (path.contains("\\")) {
             path = path.replace('\\', '/');
         }
+        return path;
+    }
+
+    private String fixPathTar( String path ) {
+        if (path == null || path.equals(".")) {
+            return path;
+        }
+
+        path = fixPathBase(path);
+
         // ensure the path is like : ./foo/bar
         if (path.startsWith("/")) {
             path = "." + path;
@@ -287,4 +303,20 @@ class DataBuilder {
         return path;
     }
 
+    private String fixPathMd5( String path ) {
+        if (path == null || path.equals(".")) {
+            return path;
+        }
+
+        path = fixPathBase(path);
+
+        // ensure the path is like : foo/bar
+        if (path.startsWith("/")) {
+            path = path.substring(1);
+        } else if (path.startsWith("./")) {
+            path = path.substring(2);
+        }
+        return path;
+    }
+
 }
