@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 The jdeb developers.
+ * Copyright 2007-2018 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,11 +16,14 @@
 
 package org.vafer.jdeb.debian;
 
-import junit.framework.TestCase;
+import org.junit.Test;
+import org.junit.Assert;
+
 import org.vafer.jdeb.changes.ChangeSet;
 
-public final class ChangesFileTestCase extends TestCase {
+public final class ChangesFileTestCase extends Assert {
 
+    @Test
     public void testToString() throws Exception {
         BinaryPackageControlFile packageControlFile = new BinaryPackageControlFile();
         packageControlFile.set("Package", "test-package");
